@@ -19,8 +19,8 @@
 #include "qscreenoutput.h"
 #include "qscreenbackend.h"
 
-#include <mode.h>
 #include <edid.h>
+#include <mode.h>
 
 #include <QGuiApplication>
 #include <QScreen>
@@ -100,8 +100,8 @@ void QScreenOutput::updateKScreenOutput(OutputPtr &output) const
     mode->setRefreshRate(m_qscreen->refreshRate());
     mode->setSize(m_qscreen->size());
 
-    const QString modename = QString::number(m_qscreen->size().width()) + QLatin1String("x") + QString::number(m_qscreen->size().height()) \
-                             + QLatin1String("@") + QString::number(m_qscreen->refreshRate());
+    const QString modename = QString::number(m_qscreen->size().width()) + QLatin1String("x") + QString::number(m_qscreen->size().height()) + QLatin1String("@")
+        + QString::number(m_qscreen->refreshRate());
     mode->setName(modename);
 
     ModeList modes;
